<?php

use App\Http\Controllers\RateMyPayController;
use Illuminate\Support\Facades\Route;

Route::middleware('auth')->prefix('rate-my-pay')->group(function () {
    // Post Management
    Route::get('/', [RateMyPayController::class, 'index'])->name('rate-my-pay.index');
    Route::get('/create/{jobExperience}', [RateMyPayController::class, 'create'])->name('rate-my-pay.create');
    Route::post('/', [RateMyPayController::class, 'store'])->name('rate-my-pay.store');
    Route::delete('/{rateMyPay}', [RateMyPayController::class, 'destroy'])->name('rate-my-pay.destroy');
});