<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ProfileController;

Route::middleware('auth')->group(function () {
    // Profile pages
    Route::get('/profile/index', [ProfileController::class, 'index'])->name('profile.index');

});
